@@ -1,6 +1,6 @@
 /*
 
-$Id: gdisp_sampling.c,v 1.15 2006/02/26 14:08:24 erk Exp $
+$Id: gdisp_sampling.c,v 1.18 2006/05/13 20:55:02 esteban Exp $
 
 -----------------------------------------------------------------------
 
@@ -147,6 +147,46 @@ gdisp_createThread ( Kernel_T               *kernel,
 }
 
 
+/*
+ * Get provider by symbol.
+ */
+static Provider_T*
+gdisp_getProviderBySymbol ( Kernel_T *kernel,
+			    Symbol_T *symbol )
+{
+
+  GList      *providerItem = (GList*)NULL;
+  Provider_T *provider     = (Provider_T*)NULL;
+
+  /*
+   * Loop over all providers, and look for the provider
+   * the given symbol belongs to.
+   */
+  providerItem = g_list_first(kernel->providerList);
+  while (providerItem != (GList*)NULL) {
+
+    provider = (Provider_T*)providerItem->data;
+
+    /*
+     * The symbol belongs to the current provider because its
+     * address is in the good address interval.
+     */
+    if (provider->pSymbolList <= symbol &&
+	symbol < provider->pSymbolList + provider->pSymbolNumber) {
+
+      return provider;
+
+    }
+
+    providerItem = g_list_next(providerItem);
+
+  }
+
+  return (Provider_T*)NULL;
+
+}
+
+
 /*
  * Main callback routine to perform timer period computation.
  */
@@ -166,7 +206,12 @@ gdisp_computeTimerPeriod ( Kernel_T         *kernel,
   plotPeriod = (*plotSystemData->plotSystem->psGetPeriod)
                                       (kernel,plotSystemData->plotData);
 
-  *timerPeriod = gdisp_computePgcd(*timerPeriod,plotPeriod);
+  if (*timerPeriod == G_MAXINT) {
+    *timerPeriod = plotPeriod;
+  }
+  else {
+    *timerPeriod = gdisp_computePgcd(*timerPeriod,plotPeriod);
+  }
 
 }
 
@@ -605,7 +650,7 @@ gdisp_samplingThread (void *data )
   requestStatus = TSP_consumer_request_sample(provider->pHandle,
 					      &provider->pSampleList);
 
-  if (requestStatus == 0) {
+  if (TSP_STATUS_OK != requestStatus) {
 
     provider->pSamplingThreadStatus = GD_THREAD_REQUEST_SAMPLE_ERROR;
     pthread_exit((void*)FALSE);
@@ -635,12 +680,16 @@ gdisp_samplingThread (void *data )
 
   tmpHashTable = hash_open('.','z');
 
-  for (sampleCpt=0; sampleCpt<sampleList->len; sampleCpt++) {
+  for (sampleCpt=0;
+       sampleCpt<sampleList->TSP_sample_symbol_info_list_t_len;
+       sampleCpt++) {
 
-    symbol = (Symbol_T*)hash_get(provider->pSymbolHashTable,
-				 sampleList->val[sampleCpt].name);
+    symbol = (Symbol_T*)
+      hash_get(provider->pSymbolHashTable,
+	       sampleList->TSP_sample_symbol_info_list_t_val[sampleCpt].name);
 
-    symbol->sPgi = sampleList->val[sampleCpt].index;
+    symbol->sPgi =
+      sampleList->TSP_sample_symbol_info_list_t_val[sampleCpt].provider_global_index;
 
     /* I can use 'sprintf' because sampling has not started yet */
     sprintf(samplePGIasStringBuffer,
@@ -664,7 +713,7 @@ gdisp_samplingThread (void *data )
 				     (TSP_sample_callback_t)NULL,
 				     (void*)NULL);
 
-  if (requestStatus == 0) {
+  if (TSP_STATUS_OK != requestStatus) {
 
     provider->pSamplingThreadStatus = GD_THREAD_SAMPLE_INIT_ERROR;
     pthread_exit((void*)FALSE);
@@ -682,8 +731,10 @@ gdisp_samplingThread (void *data )
    * As load is concerned, only "double" values are supported by TSP.
    */
   provider->pLoad    = 0;
-  provider->pMaxLoad = provider->pBaseFrequency  *
-                       provider->pSampleList.len * sizeof(gdouble);
+  provider->pMaxLoad =
+    provider->pBaseFrequency  *
+    provider->pSampleList.TSP_sample_symbol_info_list_t_len *
+    sizeof(gdouble);
 
   provider->pSamplingThreadStatus = GD_THREAD_RUNNING;
 
@@ -693,7 +744,7 @@ gdisp_samplingThread (void *data )
 					     &sampleValue,
 					     &sampleHasArrived);
 
-    if (requestStatus == FALSE) {
+    if (TSP_STATUS_OK != requestStatus) {
 
       /*
        * Out of "while" loop.
@@ -765,11 +816,7 @@ gdisp_samplingThread (void *data )
 #endif
 
       symbol->sTimeTag    = (guint)sampleValue.time;
-
-      symbol->sHasChanged =
-	sampleValue.user_value == symbol->sLastValue ? FALSE : TRUE;
-
-      symbol->sLastValue  = sampleValue.user_value;
+      symbol->sLastValue  = sampleValue.uvalue.double_value;
 
     } /* sampleHasArrived == TRUE */
 
@@ -798,7 +845,7 @@ gdisp_samplingThread (void *data )
     requestStatus = TSP_consumer_request_sample_destroy(provider->pHandle);
   }
 
-  if (requestStatus == 0) {
+  if (TSP_STATUS_OK != requestStatus) {
 
     provider->pSamplingThreadStatus = GD_THREAD_SAMPLE_DESTROY_ERROR;
 
@@ -876,7 +923,7 @@ gdisp_preSamplingThread (void *data )
     /*
      * Create the thread is only there something to be sampled...
      */
-    if (provider->pSampleList.len != 0) {
+    if (provider->pSampleList.TSP_sample_symbol_info_list_t_len != 0) {
 
       threadStatus = gdisp_createThread(kernel,
 					provider->pUrl->str,
@@ -1160,16 +1207,16 @@ gdisp_affectRequestedSymbolsToProvider ( Kernel_T *kernel )
       /*
        * Cancel any previous sampling configuration.
        */
-      provider->pSampleList.len = 0;
-      if (provider->pSampleList.val != (TSP_consumer_symbol_requested_t*)NULL)
-	g_free(provider->pSampleList.val);
-      provider->pSampleList.val = (TSP_consumer_symbol_requested_t*)NULL;
+      provider->pSampleList.TSP_sample_symbol_info_list_t_len = 0;
+      if (provider->pSampleList.TSP_sample_symbol_info_list_t_val != (TSP_sample_symbol_info_t*)NULL)
+	g_free(provider->pSampleList.TSP_sample_symbol_info_list_t_val);
+      provider->pSampleList.TSP_sample_symbol_info_list_t_val = (TSP_sample_symbol_info_t*)NULL;
 
 
       /*
        * Temporary ressource.
        */
-      elementSize = sizeof(TSP_consumer_symbol_requested_t);
+      elementSize = sizeof(TSP_sample_symbol_info_t);
       requestedSymbolArray = g_array_new(FALSE, /* zero_terminated */
 					 TRUE,  /* clear           */
 					 (guint)elementSize);
@@ -1202,9 +1249,9 @@ gdisp_affectRequestedSymbolsToProvider ( Kernel_T *kernel )
       /*
        * Transfer information to provider.
        */
-      provider->pSampleList.val =
-	(TSP_consumer_symbol_requested_t*)requestedSymbolArray->data;
-      provider->pSampleList.len = requestedSymbolArray->len;
+      provider->pSampleList.TSP_sample_symbol_info_list_t_val =
+	(TSP_sample_symbol_info_t*)requestedSymbolArray->data;
+      provider->pSampleList.TSP_sample_symbol_info_list_t_len = requestedSymbolArray->len;
 
 
       /*
@@ -1226,3 +1273,40 @@ gdisp_affectRequestedSymbolsToProvider ( Kernel_T *kernel )
   g_list_free(symbolList);
 
 }
+
+
+/*
+ * Async Write Method.
+ * Returns TRUE if success, FALSE otherwise.
+ */
+gboolean
+gdisp_asyncWriteSymbol ( Kernel_T *kernel,
+			 Symbol_T *symbol,
+			 gchar    *valueAsString )
+
+{
+
+  Provider_T *provider = (Provider_T*)NULL;
+
+  /*
+   * Check if an async-write operation is allowed.
+   */
+  if (kernel->asyncWriteIsAllowed == FALSE) {
+    return FALSE;
+  }
+
+  /*
+   * Try to get back the provider the symbol belongs to.
+   */
+  provider = gdisp_getProviderBySymbol(kernel,
+				       symbol);
+
+  if (provider == (Provider_T*)NULL) {
+    return FALSE;
+  }
+
+  /* status = TSP_consumer_request_async_sample_write(...); */
+
+  return TRUE;
+
+}
