@@ -1,6 +1,6 @@
 /*
 
-$Id: gdisp_symbols.c,v 1.8 2006/02/26 14:08:24 erk Exp $
+$Id: gdisp_symbols.c,v 1.10 2006/05/13 20:55:02 esteban Exp $
 
 -----------------------------------------------------------------------
 
@@ -133,7 +133,7 @@ gdisp_insertAndSortSymbols (Kernel_T  *kernel,
 	    /*
 	     * If symbol is not available, use special color.
 	     */
-	    if (symbolPtr->sInfo.index < 0) {
+	    if (symbolPtr->sInfo.provider_global_index < 0) {
 
 	      gtk_clist_set_foreground(GTK_CLIST(kernel->widgets.symbolCList),
 				       rowNumber, /* row */
@@ -614,8 +614,9 @@ gdisp_symbolApplyCallback (GtkWidget *applyButtonWidget,
    * Turn the filter (a coma-separated string list) into a string table.
    */
   filter = gtk_entry_get_text(GTK_ENTRY(kernel->widgets.filterEntry));
-  if (strlen(filter) == 0)
+  if (strlen(filter) == 0) {
     filter = (gchar*)NULL;
+  }
 
   gdisp_getStringTableFromStringList(filter,
 				     &stringTable,
