@@ -1,6 +1,6 @@
 /*
 
-$Id: client_res.c,v 1.14 2006/02/26 13:36:05 erk Exp $
+$Id: client_res.c,v 1.17 2006/04/24 22:17:47 erk Exp $
 
 -----------------------------------------------------------------------
 
@@ -35,13 +35,15 @@ Purpose   : Simple consummer for testing groups configuration
 -----------------------------------------------------------------------
 */
 
-#include "tsp_sys_headers.h"
+
 #include <signal.h>
 #include <unistd.h>
-#include "tsp_prjcfg.h" 
-#include "tsp_time.h" 
-#include "tsp_consumer.h"
-#include "libUTIL.h"
+
+#include <tsp_sys_headers.h>
+#include <tsp_prjcfg.h> 
+#include <tsp_time.h> 
+#include <tsp_consumer.h>
+#include <libUTIL.h>
 
 
 /*S*/
@@ -109,8 +111,8 @@ void usage (char *txt)
 
 int main(int argc, char *argv[]){
 
-  const TSP_consumer_information_t*  information;
-  TSP_consumer_symbol_requested_list_t symbols[TSP_MAX_SERVER_NUMBER];
+  const TSP_answer_sample_t*  information;
+  TSP_sample_symbol_info_list_t symbols[TSP_MAX_SERVER_NUMBER];
 
   int i, count=0;
   int nb_providers = 0;
@@ -140,13 +142,11 @@ int main(int argc, char *argv[]){
   STRACE_INFO(("Autodetect CPU : %d bits", sizeof(long)*8));
 
   /* TSP Init */
-  if(!TSP_consumer_init(&argc, &argv))
-    {
-      STRACE_ERROR(("TSP init failed"));
-      return -1;
-    }
-    
-  
+  if(TSP_STATUS_OK!=TSP_consumer_init(&argc, &argv)) {
+    STRACE_ERROR(("TSP init failed"));
+    return -1;
+  }
+      
   while ((myopt = getopt(argc, argv, "u:f:t:m:dh")) != -1)
     {
       switch(myopt)
@@ -190,11 +190,10 @@ int main(int argc, char *argv[]){
       /*-------------------------*/ 
       /* Open requested provider */
       /*-------------------------*/ 
-      if(!TSP_consumer_request_open(providers[provider], 0, 0 ))
-	{
-	  STRACE_ERROR(("TSP_request_provider_open failed"));
-	  return -1;
-	}
+      if (TSP_STATUS_OK!=TSP_consumer_request_open(providers[provider], 0, 0 )) {
+	STRACE_ERROR(("TSP_request_provider_open failed"));
+	return -1;
+      }
  
 
       /*-----------------------------*/ 
@@ -202,28 +201,28 @@ int main(int argc, char *argv[]){
       /*-----------------------------*/
       do
 	{
-	  if(!TSP_consumer_request_information(providers[provider]))
+	  if(TSP_STATUS_OK!=TSP_consumer_request_information(providers[provider]))
 	    {
 	      STRACE_ERROR(("TSP_request_provider_information failed"));
 	      return -1;
 	    }
 	  
 	  information = TSP_consumer_get_information(providers[provider]);
-	  symbols[provider].len = information->symbols.len;
-	  if(!symbols[provider].len)
+	  symbols[provider].TSP_sample_symbol_info_list_t_len = information->symbols.TSP_sample_symbol_info_list_t_len;
+	  if(!symbols[provider].TSP_sample_symbol_info_list_t_len)
 	    tsp_usleep(TSP_NANOSLEEP_PERIOD_US);
 	}
-      while(!symbols[provider].len);
+      while(!symbols[provider].TSP_sample_symbol_info_list_t_len);
       
-      symbols[provider].val = (TSP_consumer_symbol_requested_t*)calloc(symbols[provider].len, sizeof(TSP_consumer_symbol_requested_t));
-      TSP_CHECK_ALLOC(symbols[provider].val, -1);
+      symbols[provider].TSP_sample_symbol_info_list_t_val = (TSP_sample_symbol_info_t*)calloc(symbols[provider].TSP_sample_symbol_info_list_t_len, sizeof(TSP_sample_symbol_info_t));
+      TSP_CHECK_ALLOC(symbols[provider].TSP_sample_symbol_info_list_t_val, -1);
       
-      for( i = 0 ; i< symbols[provider].len ; i++)
+      for( i = 0 ; i< symbols[provider].TSP_sample_symbol_info_list_t_len ; i++)
 	{
-	  STRACE_INFO(("Id=%d Sym='%s'",i, information->symbols.val[i].name));
-	  symbols[provider].val[i].name = information->symbols.val[i].name;
-	  symbols[provider].val[i].period = period;
-	  symbols[provider].val[i].phase = 0;
+	  STRACE_INFO(("Id=%d Sym='%s'",i, information->symbols.TSP_sample_symbol_info_list_t_val[i].name));
+	  symbols[provider].TSP_sample_symbol_info_list_t_val[i].name = information->symbols.TSP_sample_symbol_info_list_t_val[i].name;
+	  symbols[provider].TSP_sample_symbol_info_list_t_val[i].period = period;
+	  symbols[provider].TSP_sample_symbol_info_list_t_val[i].phase = 0;
 	}
       
       /* chose smallest frequency */
@@ -238,12 +237,12 @@ int main(int argc, char *argv[]){
 	  /* all variables */
 	  break;
 	case 2 :
-	  symbols[provider].val[1] = symbols[provider].val[ symbols[provider].len/2];
-	  symbols[provider].val[2] = symbols[provider].val[ symbols[provider].len-1];
-	  symbols[provider].len = 3;
+	  symbols[provider].TSP_sample_symbol_info_list_t_val[1] = symbols[provider].TSP_sample_symbol_info_list_t_val[ symbols[provider].TSP_sample_symbol_info_list_t_len/2];
+	  symbols[provider].TSP_sample_symbol_info_list_t_val[2] = symbols[provider].TSP_sample_symbol_info_list_t_val[ symbols[provider].TSP_sample_symbol_info_list_t_len-1];
+	  symbols[provider].TSP_sample_symbol_info_list_t_len = 3;
 	  break;
 	case 3 :     
-	  symbols[provider].len = 10;
+	  symbols[provider].TSP_sample_symbol_info_list_t_len = 10;
 	  break;
 	default:
 	  STRACE_ERROR(("Unknown test number"));
@@ -260,28 +259,24 @@ int main(int argc, char *argv[]){
       /*---------------------*/ 
       /* Ask for sample list */
       /*---------------------*/ 
-      if(!TSP_consumer_request_sample(providers[provider],&symbols[provider]))
-	{
-	  STRACE_ERROR(("TSP_request_provider_sample failed"));
-	  return -1;
-	}
+      if(TSP_STATUS_OK!=TSP_consumer_request_sample(providers[provider],&symbols[provider])) {
+	STRACE_ERROR(("TSP_request_provider_sample failed"));
+	return -1;
+      }
     }
 
   /* in case of stop request, flush N buffers (if any) before stopping */
   buffersBeforeStop = base_frequency * 1 /* seconds */;
 
-
-  for(provider=0; provider<nb_providers; provider++)
-    {
-      /*----------------*/ 
-      /* Start sampling */
-      /*----------------*/ 
-      if(!TSP_consumer_request_sample_init(providers[provider],0,0))
-	{
-	  STRACE_ERROR(("TSP_request_provider_sample_init failed"));
-	  return -1;
-	}
-    }
+  for(provider=0; provider<nb_providers; provider++) {
+    /*----------------*/ 
+    /* Start sampling */
+    /*----------------*/ 
+    if (TSP_STATUS_OK!=TSP_consumer_request_sample_init(providers[provider],0,0)) {
+	STRACE_ERROR(("TSP_request_provider_sample_init failed"));
+	return -1;
+      }
+  }
 
   
   /*-------------------*/ 
@@ -293,18 +288,16 @@ int main(int argc, char *argv[]){
   d_wcom(""); /* No comment */
 
   res_values_nb = 0;
-  for(provider=0; provider<nb_providers; provider++)
-    {
-      for (i = 0; i < symbols[provider].len; i++)
-	{
-	  d_wnam(symbols[provider].val[i].name, "?"); /* write header with no unit */
-	}
-      res_values_nb += symbols[provider].len;
+  for(provider=0; provider<nb_providers; provider++) {
+    for (i = 0; i < symbols[provider].TSP_sample_symbol_info_list_t_len; i++) {
+      d_wnam(symbols[provider].TSP_sample_symbol_info_list_t_val[i].name, "?"); /* write header with no unit */
     }
+    res_values_nb += symbols[provider].TSP_sample_symbol_info_list_t_len;
+  }
   
   res_values = _use_dbl ? 
     calloc(( res_values_nb+1),sizeof(double)) :
-      calloc(( res_values_nb+1),sizeof(float)) ;
+    calloc(( res_values_nb+1),sizeof(float)) ;
   assert(res_values);
   
   res_value_i = 0;
@@ -312,36 +305,34 @@ int main(int argc, char *argv[]){
     {
       for(provider=0; provider<nb_providers; provider++)
 	{
-	  if(!TSP_consumer_read_sample(providers[provider], &sample, &new_sample))
-	    {
-	      stop_end = TRUE;
-	      break;
-	    }
-	  if(new_sample)
-	    {
-	      if(_use_dbl)
-		{
-		  double* d_res_values = (double*)res_values;
-		  d_res_values[res_value_i++] = sample.user_value;
-		}
-	      else
-		{
-		  float* f_res_values = (float*)res_values;
-		  f_res_values[res_value_i++] = sample.user_value;	      
-		}
-
-	      /* Received complete buffer, need to write */
-	      if( res_value_i == res_values_nb )
-		{
-		  count++;
-		  d_writ(res_values);
-		  res_value_i = 0;
-
-		  /* wait a little before stopping to flush buffers */
-		  if(stop) stop++;
-		  if(stop > buffersBeforeStop) stop_end = TRUE;
-		}
-	    }
+	  if(TSP_STATUS_OK!=TSP_consumer_read_sample(providers[provider], &sample, &new_sample)) {
+	    stop_end = TRUE;
+	    break;
+	  }
+	  if (new_sample) {
+	    if(_use_dbl)
+	      {
+		double* d_res_values = (double*)res_values;
+		d_res_values[res_value_i++] = sample.uvalue.double_value;
+	      }
+	    else
+	      {
+		float* f_res_values = (float*)res_values;
+		f_res_values[res_value_i++] = sample.uvalue.double_value;	      
+	      }
+	    
+	    /* Received complete buffer, need to write */
+	    if( res_value_i == res_values_nb )
+	      {
+		count++;
+		d_writ(res_values);
+		res_value_i = 0;
+		
+		/* wait a little before stopping to flush buffers */
+		if(stop) stop++;
+		if(stop > buffersBeforeStop) stop_end = TRUE;
+	      }
+	  }
 	  else
 	    {
 	      tsp_usleep(TSP_NANOSLEEP_PERIOD_US);
