@@ -1,6 +1,6 @@
 /*
 
-$Id: client_stdout.c,v 1.10 2006/02/26 13:36:05 erk Exp $
+$Id: client_stdout.c,v 1.12 2006/04/24 22:17:47 erk Exp $
 
 -----------------------------------------------------------------------
 
@@ -48,8 +48,8 @@ Purpose   : Simple consummer test that print samples received to stdout
 
 int main(int argc, char *argv[]){
 
-  const TSP_consumer_information_t*  information;
-  TSP_consumer_symbol_requested_list_t symbols;
+  const TSP_answer_sample_t*  information;
+  TSP_sample_symbol_info_list_t symbols;
 
   int i, j;
   int period=0;
@@ -68,11 +68,10 @@ int main(int argc, char *argv[]){
   printf ("# Launching <stdout_client> for printing symbols received #\n");
   printf ("#=========================================================#\n");
  
-  if(!TSP_consumer_init(&argc, &argv))
-    {
-      STRACE_ERROR(("TSP init failed"));
-      return -1;
-    }
+  if(TSP_STATUS_OK!=TSP_consumer_init(&argc, &argv)) {
+    STRACE_ERROR(("TSP init failed"));
+    return -1;
+  }
 
   switch (argc-1) { /* No Breaks please */
   case 5: 
@@ -125,7 +124,7 @@ int main(int argc, char *argv[]){
   /*-------------------------------------------------------------------------------------------------------*/ 
   /* Le 1er provider existe puisqu'il y en a au moins 1 */
 
-  if(!TSP_consumer_request_open(provider, 0, 0))
+  if(TSP_STATUS_OK!=TSP_consumer_request_open(provider, 0, 0))
     {
       STRACE_ERROR(("TSP_request_provider_open failed"));
       STRACE_TEST(("STAGE 001 | STEP 002 : FAILED"));
@@ -137,7 +136,7 @@ int main(int argc, char *argv[]){
   /*-------------------------------------------------------------------------------------------------------*/ 
   /* TEST : STAGE 001 | STEP 003 */
   /*-------------------------------------------------------------------------------------------------------*/ 
-  if(!TSP_consumer_request_information(provider))
+  if(TSP_STATUS_OK!=TSP_consumer_request_information(provider))
     {
       STRACE_ERROR(("TSP_request_provider_information failed"));
       STRACE_TEST(("STAGE 001 | STEP 003 : FAILED"));
@@ -145,7 +144,7 @@ int main(int argc, char *argv[]){
     }
   
   /* be wild, ask twice to try to trigger mem leak  */
-  if(!TSP_consumer_request_information(provider))
+  if(TSP_STATUS_OK!=TSP_consumer_request_information(provider))
     {
       STRACE_ERROR(("TSP_request_provider_information failed"));
       STRACE_TEST(("STAGE 001 | STEP 003 : FAILED"));
@@ -156,20 +155,20 @@ int main(int argc, char *argv[]){
   information = TSP_consumer_get_information(provider);
 
   /* Check total symbol number */
-  if(information->symbols.len < 1 || information->symbols.len > 999999)
+  if(information->symbols.TSP_sample_symbol_info_list_t_len < 1 || information->symbols.TSP_sample_symbol_info_list_t_len > 999999)
     {
-      STRACE_ERROR(("The total number of symbols should be fair, and not %d",information->symbols.len));
+      STRACE_ERROR(("The total number of symbols should be fair, and not %d",information->symbols.TSP_sample_symbol_info_list_t_len));
       STRACE_TEST(("STAGE 001 | STEP 003 : FAILED"));
       return -1;      
     }
 
   /* Compare symbols names */
-  for( i = 1 ; i<  information->symbols.len ; i++)
+  for( i = 1 ; i<  information->symbols.TSP_sample_symbol_info_list_t_len ; i++)
     {
       sprintf(symbol_buf, "Symbol%d",i);
-      if(strcmp(symbol_buf,  information->symbols.val[i].name))
+      if(strcmp(symbol_buf,  information->symbols.TSP_sample_symbol_info_list_t_val[i].name))
 	{
-printf("%s != %s\n", symbol_buf,  information->symbols.val[i].name);
+printf("%s != %s\n", symbol_buf,  information->symbols.TSP_sample_symbol_info_list_t_val[i].name);
 	  STRACE_ERROR(("Symbol name corrupted"));
 	  STRACE_TEST(("STAGE 001 | STEP 003 : FAILED"));
 	  return -1;
@@ -180,45 +179,45 @@ printf("%s != %s\n", symbol_buf,  information->symbols.val[i].name);
   STRACE_TEST(("STAGE 001 | STEP 003 : PASSED"));
 
   if (nb_samples>0)
-    symbols.len = nb_samples;
+    symbols.TSP_sample_symbol_info_list_t_len = nb_samples;
   else
-    symbols.len = information->symbols.len;
-  symbols.val = (TSP_consumer_symbol_requested_t*)calloc(symbols.len, sizeof(TSP_consumer_symbol_requested_t));
-  TSP_CHECK_ALLOC(symbols.val, -1);
+    symbols.TSP_sample_symbol_info_list_t_len = information->symbols.TSP_sample_symbol_info_list_t_len;
+  symbols.TSP_sample_symbol_info_list_t_val = (TSP_sample_symbol_info_t*)calloc(symbols.TSP_sample_symbol_info_list_t_len, sizeof(TSP_sample_symbol_info_t));
+  TSP_CHECK_ALLOC(symbols.TSP_sample_symbol_info_list_t_val, -1);
 
   /* Change period of sampling for each client */
-  for(i = 0 ; i < symbols.len ; i++)
+  for(i = 0 ; i < symbols.TSP_sample_symbol_info_list_t_len ; i++)
     {
-      symbols.val[i].name = information->symbols.val[i].name;
-      symbols.val[i].period = period;
-      symbols.val[i].phase = 0;
+      symbols.TSP_sample_symbol_info_list_t_val[i].name = information->symbols.TSP_sample_symbol_info_list_t_val[i].name;
+      symbols.TSP_sample_symbol_info_list_t_val[i].period = period;
+      symbols.TSP_sample_symbol_info_list_t_val[i].phase = 0;
     }
 
-  STRACE_INFO(("Asking for %d symboles", symbols.len));
+  STRACE_INFO(("Asking for %d symboles", symbols.TSP_sample_symbol_info_list_t_len));
   /*-------------------------------------------------------------------------------------------------------*/ 
   /* TEST : STAGE 001 | STEP 004 */
   /*-------------------------------------------------------------------------------------------------------*/ 
-  if(!TSP_consumer_request_sample(provider, &symbols))
+  if(TSP_STATUS_OK!=TSP_consumer_request_sample(provider, &symbols))
     {
       STRACE_ERROR(("TSP_request_provider_sample failed"));
       STRACE_TEST(("STAGE 001 | STEP 004 : FAILED"));
       return -1;
     }
   /* be wild, ask twice to try to trigger mem leak  */
-  if(!TSP_consumer_request_sample(provider, &symbols))
+  if(TSP_STATUS_OK!=TSP_consumer_request_sample(provider, &symbols))
     {
       STRACE_ERROR(("TSP_request_provider_sample failed"));
       STRACE_TEST(("STAGE 001 | STEP 004 : FAILED"));
       return -1;
     }
 
-  free(symbols.val);
+  free(symbols.TSP_sample_symbol_info_list_t_val);
 
   STRACE_TEST(("STAGE 001 | STEP 004 : PASSED"));
   /*-------------------------------------------------------------------------------------------------------*/ 
   /* TEST : STAGE 001 | STEP 005 */
   /*-------------------------------------------------------------------------------------------------------*/ 
-  if(!TSP_consumer_request_sample_init(provider, 0, 0))
+  if(TSP_STATUS_OK!=TSP_consumer_request_sample_init(provider, 0, 0))
     {
       STRACE_ERROR(("TSP_request_provider_sample_init failed"));
       STRACE_TEST(("STAGE 001 | STEP 005 : FAILED"));
@@ -240,7 +239,7 @@ printf("%s != %s\n", symbol_buf,  information->symbols.val[i].name);
       
       new_sample = FALSE;
       do{
-	if(TSP_consumer_read_sample(provider,&sample, &new_sample))
+	if(TSP_STATUS_OK==TSP_consumer_read_sample(provider,&sample, &new_sample))
 	  {
 	    if(new_sample)
 	      {
@@ -256,7 +255,7 @@ printf("%s != %s\n", symbol_buf,  information->symbols.val[i].name);
 		if(i == 1 )
 		  {
 		    count_samples++;
-		    printf ("TSP : Sample nb[%d] time=%d val=%f\n", count_samples, sample.time, sample.user_value);
+		    printf ("TSP : Sample nb[%d] time=%d val=%f\n", count_samples, sample.time, sample.uvalue.double_value);
 		  }
 
 		calc = calc_func(i,sample.time);
@@ -264,9 +263,9 @@ printf("%s != %s\n", symbol_buf,  information->symbols.val[i].name);
 		/* i = 0 is t */
 		if(i != 0)
 		  {
-		    if( (ABS(sample.user_value - calc) > 1e-7) && (t == (sample.time - 1)) )
+		    if( (ABS(sample.uvalue.double_value - calc) > 1e-7) && (t == (sample.time - 1)) )
 		      {
-			STRACE_ERROR(("!!!!ERROR : T=%u, I=%d, V1=%f, V2=%f", sample.time,i,sample.user_value,calc ));			
+			STRACE_ERROR(("!!!!ERROR : T=%u, I=%d, V1=%f, V2=%f", sample.time,i,sample.uvalue.double_value,calc ));			
 			all_data_ok = FALSE;
 		      }
 		  }
@@ -284,12 +283,12 @@ printf("%s != %s\n", symbol_buf,  information->symbols.val[i].name);
 			/* --------------- */
 			/* Close providers */
 			/* --------------- */
-			if(!TSP_consumer_request_sample_destroy(provider))
+			if(TSP_STATUS_OK!=TSP_consumer_request_sample_destroy(provider))
 			  {
 			    STRACE_ERROR(("Function TSP_consumer_request_sample_destroy failed" ));	 
 			  }
 			
-			if(!TSP_consumer_request_close(provider))
+			if(TSP_STATUS_OK!=TSP_consumer_request_close(provider))
 			  {
 			    STRACE_ERROR(("Function TSP_consumer_request_close failed" ));			    
 			  }
