@@ -1,6 +1,6 @@
 /*
 
-$Header: /cvsroot/tsp/tsp/src/core/ctrl/tsp_group_algo_data.h,v 1.5 2006/02/26 13:36:05 erk Exp $
+$Header: /cvsroot/tsp/tsp/src/core/ctrl/tsp_group_algo_data.h,v 1.7 2006/04/12 06:56:03 erk Exp $
 
 -----------------------------------------------------------------------
 
@@ -41,11 +41,16 @@ for performance reason may include this header
 #define _TSP_GROUP_ALGO_DATA_H
 
 #include "tsp_data_sender.h"
+#include <tsp_encoder.h>
 
 struct TSP_algo_group_item_t
 {
   void* data;
-    
+  int   dimension;
+  u_int offset;
+  u_int nelem;
+
+
   TSP_data_encoder_t data_encoder;
 };
 
