@@ -1,6 +1,6 @@
 /*
 
-$Header: /cvsroot/tsp/tsp/src/core/ctrl_init/tsp_provider_init.h,v 1.12 2006/02/26 13:36:05 erk Exp $
+$Header: /cvsroot/tsp/tsp/src/core/ctrl_init/tsp_provider_init.h,v 1.14 2006/04/24 21:05:34 erk Exp $
 
 -----------------------------------------------------------------------
 
@@ -56,19 +56,21 @@ BEGIN_C_DECLS
  * call to the TSP provider library.
  * Call this function at the start of your main function
  * with the received argc/argv. Then use the modified argc/argv.
- * @param theGLU the GLU object to be used by this provider.
- * @param argc You must provide the real argc before using it
- * @param argv You must provide the real argv before using it
- * @return TRUE or FALSE. OK = TRUE.
+ * @param[in,out] theGLU the GLU object to be used by this provider.
+ * @param[in,out] argc You must provide the real argc before using it
+ * @param[in,out] argv You must provide the real argv before using it
+ * @return TSP_STATUS_OK on success other code on failure.
  */
-int TSP_provider_init(GLU_handle_t* theGLU, int* argc, char** argv[]);
+int32_t
+TSP_provider_init(GLU_handle_t* theGLU, int* argc, char** argv[]);
 
 /**
  * Finalize the TSP provider library.
  * After this call the TSP provider library should
  * not be called anymore.
  */
-void TSP_provider_end(void);
+void 
+TSP_provider_end(void);
 
 /**
  * The different value of the TSP
@@ -94,9 +96,10 @@ void TSP_provider_end(void);
  *              TSP asynchronous request channel (ONC RPC, XML RPC, SOAP, CORBA,...).
  *              The number of thread launched may vary dynamically.
  *       - 0x11 dynamic blocking mode, this function will block forever.
- * @return TRUE or FALSE. OK = TRUE.
+ * @return TSP_STATUS_OK on success other code on failure.
  */
-int TSP_provider_run(int spawn_mode);
+int32_t
+TSP_provider_run(int spawn_mode);
 
 
 /**
@@ -118,10 +121,12 @@ int TSP_provider_run(int spawn_mode);
  *       - 0x0100 publish to local SNMP agent (TODO).
  * @return String table or NULL.
  */
-char **TSP_provider_urls(int pub_mode);
+char**
+TSP_provider_urls(int pub_mode);
 
 
-void TSP_provider_print_usage(void);
+void 
+TSP_provider_print_usage(void);
 
 /**  @} */
 
