@@ -1,6 +1,6 @@
 /*
 
-$Id: tsp_consumer.h,v 1.25 2006/02/26 13:36:05 erk Exp $
+$Id: tsp_consumer.h,v 1.34 2006/05/03 21:16:38 erk Exp $
 
 -----------------------------------------------------------------------
 
@@ -53,96 +53,43 @@ Purpose   : Main interface for the TSP consumer library
 
 /*------------------------------ ENUM ---------------------------------*/
  
-/**
- * Status for a futur get_last_error function.
- * FIXME : not used for now. Anyway, this enum
- * must be completed
- */
-enum TSP_consumer_status_t {
-	TSP_CONSUMER_STATUS_OK,
-	TSP_CONSUMER_STATUS_ERROR_UNKNOWN,
-	TSP_CONSUMER_STATUS_ERROR_VERSION
-};
 
 /*-------------------------- STRUCTURES -------------------------------*/
 
 
 
 /** Structure to get each sample */
-struct TSP_sample_t
+typedef struct TSP_sample
 {
   int time;
   int provider_global_index;
-  double user_value;
+  int32_t array_index;
+  TSP_datatype_t type; 
+ 
+  union {
+    double        double_value;
+    float         float_value;
+    int8_t        int8_value;
+    int16_t       int16_value;
+    int32_t       int32_value;
+    int64_t       int64_value;    
+    uint8_t       uint8_value;
+    uint16_t      uint16_value;
+    uint32_t      uint32_value;
+    uint64_t      uint64_value;
+    char          char_value;
+    unsigned char uchar_value;
+    int8_t        raw_value;
+  } uvalue;
 
+} TSP_sample_t;
 
-};
-
-typedef struct TSP_sample_t TSP_sample_t;
 
 /** Callback function type used to receive a sample item.
 FIXME : The callback function should transmit the error code
 too ( ex :  typedef void (*TSP_sample_callback_t) (TSP_sample_t* sample, TSP_consumer_status_t status);  */
 typedef void (*TSP_sample_callback_t) (TSP_sample_t* sample, void* user_data); 
 
-
-/** Structure used to request symbols */
-struct TSP_consumer_symbol_requested_t
-{
-  char* name;
-  int index;
-  int period;
-  int phase;
-  /* FIXME : we need a way to tell when
-     we want a RAW, STRING or DOUBLE
-     char xdr_tsp_t[4]; */
-
-};
-
-typedef struct TSP_consumer_symbol_requested_t TSP_consumer_symbol_requested_t;
-
-struct TSP_consumer_symbol_requested_list_t
-{
-  int len;
-  TSP_consumer_symbol_requested_t* val;
-};
-
-typedef struct TSP_consumer_symbol_requested_list_t TSP_consumer_symbol_requested_list_t;
-
-
-/** Structure used to read all symbols info */
-struct TSP_consumer_symbol_info_t
-{
-  char* name;
-  int index;
-  /* FIXME : char xdr_tsp_t[4]; Symbol type*/
-  /* FIXME :  u_int dimension ; Symbol dimension, for vectors*/
-};
-
-typedef struct TSP_consumer_symbol_info_t TSP_consumer_symbol_info_t;
-
-
-struct TSP_consumer_symbol_info_list_t
-{
-  int len;
-  TSP_consumer_symbol_info_t* val;
-};
-
-typedef struct TSP_consumer_symbol_info_list_t TSP_consumer_symbol_info_list_t;
-
-/** return all information about a provider */
-struct TSP_consumer_information_t
-{
-  /* FIXME : int provider_timeout;*/
-  double base_frequency;
-  int max_period;
-  int max_client_number;
-  int current_client_number;
-  TSP_consumer_symbol_info_list_t symbols;
-};
-
-typedef struct TSP_consumer_information_t TSP_consumer_information_t;
-
 typedef struct TSP_consumer_async_sample_t
 {
     int provider_global_index;
@@ -183,16 +130,18 @@ BEGIN_C_DECLS
  * This function must be called once.
  * @param argc Use the argc main arg before using it
  * @param argv Use the argv main arg before using it
- * @return TRUE = OK
+ * @return TSP_STATUS_OK on success TSP_STATUS_ERROR_xxx on error.
  */
-int TSP_consumer_init(int* argc, char** argv[]);
+int32_t 
+TSP_consumer_init(int* argc, char** argv[]);
 
 /**
-* End of TSP library use
-* call this function when you are done with the librairy.
-* This function must be called once.
-*/
-void TSP_consumer_end();
+ * End of TSP library use
+ * call this function when you are done with the librairy.
+ * This function must be called once.
+ */
+void 
+TSP_consumer_end();
 
 
 /*----
@@ -210,8 +159,8 @@ void TSP_consumer_end();
 * @param nb_providers Total number of providers in 'providers' array
 */
 void TSP_consumer_connect_all(const char* host_name,
-			   TSP_provider_t** providers,
-			   int* nb_providers);
+			      TSP_provider_t** providers,
+			      int* nb_providers);
 
 /**
 * Disconnected all found providers.
@@ -258,8 +207,6 @@ const char* TSP_consumer_get_connected_name(TSP_provider_t provider);
 void TSP_consumer_disconnect_one(TSP_provider_t provider);
 
 
-	  
-
 /** 
  * Ask the provider for a new consumer session.
  * This function must be called and must succed for the program to be able to call
@@ -267,7 +214,7 @@ void TSP_consumer_disconnect_one(TSP_provider_t provider);
  * @param provider The provider handle
  * @param custom_argc Custom provider data stream initialisation (optional : set 0)
  * @param custom_argv Custom provider data stream initialisation (optional : set 0)
- * @return TRUE or FALSE. TRUE = OK.
+ * @return TSP_STATUS_OK on success TSP_STATUS_ERROR_xxx on error.
  * custom_argc and custom_argv works like main argc and argv :
  * - custom_argv[0] is ignored but a real string must be provided 
  * (any string will do, but there MUST be a string, even an empty
@@ -285,14 +232,26 @@ void TSP_consumer_disconnect_one(TSP_provider_t provider);
  * It is a way to prevent the user from providing initialisation parameters thrue the command
  * line.
  */
-int TSP_consumer_request_open(TSP_provider_t provider, int custom_argc, char* custom_argv[]);
+int32_t 
+TSP_consumer_request_open(TSP_provider_t provider, int custom_argc, char* custom_argv[]);
+
+/**
+ * Return the TSP channel Id associated with this
+ * TSP session if a TSP Request Open has already been sent to this
+ * provider.
+ * @param provider the TSP session to provider
+ * @return the channel Id  if the session is open -1 if session not opened. 
+ */
+uint32_t
+TSP_consumer_get_channel_id(TSP_provider_t provider);
 
 /**
  * Close the session.
  * @param provider The provider handle
- * @return TRUE or FALSE. TRUE = OK.
+ * @return TSP_STATUS_OK on success TSP_STATUS_ERROR_xxx on error.
  */
-int TSP_consumer_request_close(TSP_provider_t provider);
+int32_t
+TSP_consumer_request_close(TSP_provider_t provider);
 
 
 /** 
@@ -302,9 +261,10 @@ int TSP_consumer_request_close(TSP_provider_t provider);
  * This function should be called multiple times only to refresh
  * the structure returned by the TSP_consumer_get_information function.
  * @param provider The provider handle
- * @return TRUE or FALSE. TRUE = OK.
+ * @return TSP_STATUS_OK on success TSP_STATUS_ERROR_xxx on error.
  */				  
-int TSP_consumer_request_information(TSP_provider_t provider);
+int32_t 
+TSP_consumer_request_information(TSP_provider_t provider);
 
 /** 
  * Request provider information.
@@ -315,9 +275,33 @@ int TSP_consumer_request_information(TSP_provider_t provider);
  * @param provider The provider handle
  * @param filter_kind the kind of filter
  * @param filter_string the filter string
- * @return TRUE or FALSE. TRUE = OK.
+ * @return TSP_STATUS_OK on success TSP_STATUS_ERROR_xxx on error.
  */				  
-int TSP_consumer_request_filtered_information(TSP_provider_t provider, int filter_kind, char* filter_string);
+int32_t 
+TSP_consumer_request_filtered_information(TSP_provider_t provider, int filter_kind, char* filter_string);
+
+/** 
+ * Request provider extended information.
+ * Ask the provider for extended informations for the specified PGI.
+ * This function should be called multiple times only to refresh
+ * the structure returned by the TSP_consumer_get_extended_information function.
+ * @param[in] provider The provider handle
+ * @param[in] pgis the list of PGI for which we want extended informations
+ * @param[in] pgis_len the length of the pgis array
+ * @return TSP_STATUS_OK on success TSP_STATUS_ERROR_xxx on error.
+ */
+int32_t 
+TSP_consumer_request_extended_information(TSP_provider_t provider, int32_t* pgis, int32_t pgis_len);
+
+/** 
+ * Retrieve the provider extended information list.
+ * Get the provider information asked by TSP_consumer_request_information
+ * This function may be called multiple times per session
+ * @param provider The provider handle
+ * @return the provider extended information structure
+ */
+const TSP_sample_symbol_extended_info_list_t*  
+TSP_consumer_get_extended_information(TSP_provider_t provider);
 
 /** 
  * Retrieve the provider list.
@@ -326,7 +310,7 @@ int TSP_consumer_request_filtered_information(TSP_provider_t provider, int filte
  * @param provider The provider handle
  * @return the provider information structure
  */				  
-const TSP_consumer_information_t* TSP_consumer_get_information(TSP_provider_t provider);
+const TSP_answer_sample_t* TSP_consumer_get_information(TSP_provider_t provider);
 
 /** 
  * Ask the provider for a list of symbols.
@@ -340,10 +324,11 @@ const TSP_consumer_information_t* TSP_consumer_get_information(TSP_provider_t pr
  * the structure returned by the TSP_consumer_get_requested_sample function.
  * @param provider The provider handle
  * @param symbols The request symbols list
- * @return TRUE or FALSE. TRUE = OK.
+ * @return TSP_STATUS_OK on success TSP_STATUS_ERROR_xxx on error.
  */				  
-int TSP_consumer_request_sample(TSP_provider_t provider,
-				TSP_consumer_symbol_requested_list_t* symbols);
+int32_t 
+TSP_consumer_request_sample(TSP_provider_t provider,
+			    TSP_sample_symbol_info_list_t* symbols);
 
 /** 
  * Retrieve the symbols requested list.
@@ -352,7 +337,7 @@ int TSP_consumer_request_sample(TSP_provider_t provider,
  * @param provider The provider handle
  * @return the requested symbols list.
  */				  
-const TSP_consumer_symbol_requested_list_t* TSP_consumer_get_requested_sample(TSP_provider_t provider);
+const TSP_sample_symbol_info_list_t* TSP_consumer_get_requested_sample(TSP_provider_t provider);
 
 /** 
  * Prepare and start the sampling sequence.
@@ -363,16 +348,18 @@ const TSP_consumer_symbol_requested_list_t* TSP_consumer_get_requested_sample(TS
  * function instead. DO NOT USE BOTH. Using the TSP_consumer_read_sample function
  * is easier as you do not have to deal with multi-thread problems, but the callback
  * function is CPU friendlier (theoricaly at least...)
- * @return TRUE or FALSE. TRUE = OK.
+ * @return TSP_STATUS_OK on success TSP_STATUS_ERROR_xxx on error.
  */				      
-int TSP_consumer_request_sample_init(TSP_provider_t provider, TSP_sample_callback_t callback, void* user_data);    
+int32_t 
+TSP_consumer_request_sample_init(TSP_provider_t provider, TSP_sample_callback_t callback, void* user_data);    
 
 /** 
  * Stop and destroy the sampling sequence
  * @param provider The provider handle
- * @return TRUE or FALSE. TRUE = OK.
+ * @return TSP_STATUS_OK on success TSP_STATUS_ERROR_xxx on error.
  */				      
-int TSP_consumer_request_sample_destroy(TSP_provider_t provider);    
+int32_t
+TSP_consumer_request_sample_destroy(TSP_provider_t provider);    
 
 /** 
  * Read a sample symbol.
@@ -380,23 +367,63 @@ int TSP_consumer_request_sample_destroy(TSP_provider_t provider);
  * @param sample The returned symbol if there is one
  * @param new_sample When TRUE, there is a new sample, else the sample value is
  *                    meaningless
- * @return TRUE or FALSE. FALSE = There is an error (but we can not know it for now).
+ * @return TSP_STATUS_OK on success TSP_STATUS_ERROR_xxx on error.
  * @todo
  *  - Some kind of get_last_error func must be implemented to read
  *    the error codes (EOF, RECONF ... ).
  *  - When the other types will be implemented (RAW, STRING) the TSP_sample_t
  *    type will not work anymore as it is double specific for now.
  */				          
-int TSP_consumer_read_sample(TSP_provider_t provider,
-			     TSP_sample_t* sample,
-			     int* new_sample);
+int32_t 
+TSP_consumer_read_sample(TSP_provider_t provider,
+			 TSP_sample_t* sample,
+			 int* new_sample);
 
 
-int TSP_consumer_request_async_sample_write(TSP_provider_t provider,TSP_consumer_async_sample_t* async_sample_write);
+/**
+ * Send a TSP asynchronous sample write request.
+ * @param[in] provider the TSP session onto we want to send the request
+ * @param[in] async_sample_write the async write message itself
+ * @return TSP_STATUS_OK on success other TSP_STATUS_ERROR on failure.
+ */
+int32_t 
+TSP_consumer_request_async_sample_write(TSP_provider_t provider,
+					TSP_consumer_async_sample_t* async_sample_write);
 
-int TSP_consumer_request_async_sample_read(TSP_provider_t provider,TSP_consumer_async_sample_t* async_sample_read);
+/**
+ * Send a TSP asynchronous sample read request.
+ * @param[in] provider the TSP session onto we want to send the request
+ * @param[in,out] async_sample_read the async read message itself
+ *                on entry describes the symbol to read
+ *                on return contains the read value (if success)
+ * @return TSP_STATUS_OK on success other TSP_STATUS_ERROR on failure.
+ */
+int32_t 
+TSP_consumer_request_async_sample_read(TSP_provider_t provider,
+				       TSP_consumer_async_sample_t* async_sample_read);
 
-void TSP_consumer_print_invalid_symbols(FILE*, TSP_consumer_symbol_requested_list_t* symbols, const char* tsp_provider_url);
+/**
+ * Print the symbols flagged as invalid
+ * in the provided sample symbol info list.
+ * @param[in]  fs the STDIO file stream
+ * @param[in]  symbols the list of symbol to analyse
+ * @param[in]  tsp_provider_url the provider TSP URL.
+ */
+void TSP_consumer_print_invalid_symbols(FILE* fs, 
+					TSP_sample_symbol_info_list_t* symbols, 
+					const char* tsp_provider_url);
+
+/**
+ * Convert a sample value to double.
+ * This is a convenient for easy simple double type
+ * to multi-type transition.
+ * Numeric sample value a translated to numeric double values
+ * whereas char, uchar and raw are translated to 0.
+ * @param sample the sample to convert
+ * @return the double value of the sample
+ */
+double 
+TSP_sample2double(TSP_sample_t sample);
 
 /** @} end group TSP_ConsumerLib */ 
 
