@@ -1,6 +1,6 @@
 /*
 
-$Header: /cvsroot/tsp/tsp/src/core/driver/tsp_group_data.h,v 1.6 2006/02/26 13:36:05 erk Exp $
+$Header: /cvsroot/tsp/tsp/src/core/driver/tsp_group_data.h,v 1.8 2006/04/07 10:37:17 morvan Exp $
 
 -----------------------------------------------------------------------
 
@@ -45,14 +45,20 @@ for performance reason may include this header
 #include "tsp_datastruct.h"
 #include "tsp_data_receiver.h"
 
+#include <tsp_decoder.h>
+#include <tsp_encoder.h>
+
 struct TSP_group_item_t
 {
+  TSP_sample_symbol_info_t* symbol_info;
   int provider_global_index;
 
   int sizeof_encoded_item;
 
   TSP_data_decoder_t data_decoder;
 
+ 
+
 };
 
 typedef struct TSP_group_item_t TSP_group_item_t;
@@ -64,6 +70,8 @@ struct TSP_group_t
   int sizeof_encoded_group;
     
   TSP_group_item_t* items;
+
+  void * decode_buffer;
     
 };
 
