@@ -1,6 +1,6 @@
 /*
 
-$Header: /cvsroot/tsp/tsp/src/core/include/tsp_simple_trace.h,v 1.17 2006/02/26 13:36:05 erk Exp $
+$Header: /cvsroot/tsp/tsp/src/core/include/tsp_simple_trace.h,v 1.20 2006/05/26 12:20:42 deweerdt Exp $
 
 -----------------------------------------------------------------------
 
@@ -62,18 +62,20 @@ Purpose   : Some trace macro
 #endif
 				  
 #ifdef  USE_STRACE
-# define STRACE_IO(text) SIMPLE_TRACE(8, "i/o", text)
-# define STRACE_DEBUG(text) SIMPLE_TRACE(4, "debug", text)
+# define STRACE_TEST(text) SIMPLE_TRACE(32, "TEST", text)
+# define STRACE_IO(text) SIMPLE_TRACE(16, "I/O", text)
+# define STRACE_DEBUG(text) SIMPLE_TRACE(8, "Debug", text)
+# define STRACE_REQUEST(text) SIMPLE_TRACE(4, "TSP Request", text)
 # define STRACE_INFO(text) SIMPLE_TRACE(2, "Info", text)
-# define STRACE_TEST(text) SIMPLE_TRACE(1, "TEST", text)
 #else
+# define STRACE_TEST(text)
 # define STRACE_IO(text)
 # define STRACE_DEBUG(text)
+# define STRACE_REQUEST(text)
 # define STRACE_INFO(text)
-# define STRACE_TEST(text)
 #endif
 
-#define STRACE_WARNING(text) SIMPLE_TRACE(2, "WarninG", text)
+#define STRACE_WARNING(text) SIMPLE_TRACE(1, "WarninG", text)
 #define STRACE_ERROR(text) SIMPLE_TRACE(0,"ERROR", text)
 
 #endif /*_SIMPLE_TRACE_H*/
