@@ -1,6 +1,6 @@
 /*
 
-$Header: /cvsroot/tsp/tsp/src/core/rpc/tsp_client.c,v 1.15 2006/02/26 13:36:06 erk Exp $
+$Header: /cvsroot/tsp/tsp/src/core/rpc/tsp_client.c,v 1.17 2006/04/03 16:07:36 erk Exp $
 
 -----------------------------------------------------------------------
 
@@ -369,14 +369,13 @@ int* TSP_request_async_sample_write(const TSP_async_sample_t* async_sample_write
   STRACE_IO(("-->OUT"));
   	
  return result;
-}	
+} /* end of async_sample_write */	
 
-TSP_async_sample_t* TSP_request_async_sample_read(const TSP_async_sample_t* async_sample_read, TSP_server_t server)
+TSP_async_sample_t* TSP_request_async_sample_read(const TSP_async_sample_t* async_sample_read, 
+						  TSP_server_t server)
 {
   TSP_async_sample_t* result;
   
-  STRACE_IO(("-->IN"));
-  
 
 /*   switch (async_sample_read->data.data_len) { */
 /*   case 2:  */
@@ -400,5 +399,19 @@ TSP_async_sample_t* TSP_request_async_sample_read(const TSP_async_sample_t* asyn
 	
   STRACE_IO(("-->OUT"));
   	
+  return result;
+} /* end of async_sample_read */	
+
+TSP_answer_extended_information_t* 
+TSP_request_extended_information(const TSP_request_extended_information_t* req_extinfo, TSP_server_t server)
+{
+
+  TSP_answer_extended_information_t* result;
+	
+  LOCAL_RPCCHECK_0;
+	
+  result = tsp_request_extended_information_1(*req_extinfo, server);
+  TSP_STRACE_RPC_ERROR(server, result);
+  
   return result;
 }	
