@@ -1,4 +1,4 @@
- /*!  \file 
+ /*
 
 $Header $
 
@@ -47,6 +47,15 @@ Purpose   : posix implementation for VXWORKS
 #include "tsp_provider_init.h"
 #include "tsp_const_def.h"
 
+/**
+ * @defgroup BB_TSPProvider BB TSP Provider
+ * A TSP BlackBoard provider, this provider attach itself
+ * to an existing @ref BlackBoard and offers all the published
+ * data as TSP symbols.
+ * @ingroup TSP_Providers
+ */
+
+
 #ifndef VXWORKS
 
 int 
@@ -70,6 +79,7 @@ main (int argc, char ** argv) {
   bb_tsp_provider_initialise(&argc,&argv,
 			     TSP_ASYNC_REQUEST_SIMPLE | TSP_ASYNC_REQUEST_NON_BLOCKING,
 			     argv[1],atof(argv[2]), 0);
+  TSP_provider_urls(TSP_PUBLISH_URLS_PRINT);
   sigwait(&allsigs, &whatsig);
   bb_tsp_provider_finalize();
   
