@@ -1,6 +1,6 @@
 /*
 
-$Header: /cvsroot/tsp/tsp/src/util/libbb/bb_utils.h,v 1.8 2006/02/26 13:36:06 erk Exp $
+$Header: /cvsroot/tsp/tsp/src/util/libbb/bb_utils.h,v 1.10 2006/04/25 21:09:08 erk Exp $
 
 -----------------------------------------------------------------------
 
@@ -37,11 +37,11 @@ Purpose   : Blackboard Idiom utilities
 #ifndef _BB_UTILS_H_
 #define _BB_UTILS_H_
 
-#include "tsp_abs_types.h"
-
 #include <sys/ipc.h>
 #include <sys/types.h>
 
+#include <tsp_abs_types.h>
+
 /**
  * @defgroup BBUtilsLib The BB Utilities Library
  * @ingroup BlackBoard
@@ -182,11 +182,11 @@ bb_utils_parseone_array(const char* provided_symname,
 			char** remaining_symname, int32_t remaining_symname_len);
 
 int32_t
-bb_untils_parsearrayname(const char* provided_symname, 
-			 char* parsed_symname,
-			 const int32_t parsed_symname_maxlen,
-			 int32_t* array_index, 
-			 int32_t* array_index_len);
+bb_utils_parsearrayname(const char* provided_symname, 
+			char* parsed_symname,
+			const int32_t parsed_symname_maxlen,
+			int32_t* array_index, 
+			int32_t* array_index_len);
 
 /** @} */
 
